<?php
/*
 * Wooconvo vendor email class
*/


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Wooemail_Vendor_Msg extends WC_Email {
    
  
    public function __construct() {

        // set ID, this simply needs to be a unique name
        $this->id   = 'wooconvo_chat';

        // this is the title in WooCommerce Email settings
        $this->title = __('WooConvo - New Message Received','wooconvo');

        // this is the description in WooCommerce email settings
        $this->description = 'Send email when new message sent by customer or vendor';

        // these are the default heading and subject lines that can be overridden using the settings
        $this->heading = 'New Message Receive';
        $this->subject = 'New Message Receive';
        $this->recipient = $this->get_option('recipient');
        $this->email_type = $this->get_option('email_type');
        
        $this->template_html    = 'wooconvo-email-html.php';
        $this->template_plain    = 'wooconvo-email-plain.php';
        
        $this->placeholders   = array(
				'{order_date}'   => '',
				'{order_number}' => '',
				'{message_text}' => '',
				'{billing_first_name}' => '',
				'{billing_last_name}' => '',
			);
        
        $this->template_base    = WOOCONVO_PLUGIN_PATH.'/templates/vendor/';
        
        // trigger when new message sent
        add_action( 'wooconvo_email_alert_notification', array( $this, 'trigger'), 10, 5 );
        
        // Call parent constructor to load any other defaults not explicity defined here
        parent::__construct();
    }
    
   
    public function trigger( $order_id, $is_admin, $email_to, $wooconvo_message, $wooconvo ) {
        
        $this->setup_locale();
        
        if ( ! $order_id )
            return;
            
        // The recepeint
        if(!empty($this->recipient) ) {
            $email_to = array_merge($email_to, explode(',', $this->recipient));
        }
        
        $this->recipient = implode(',', $email_to);
        
        $order = wc_get_order( $order_id );
        
        $order_number = $order_id;
        if(!empty($order->get_order_number()) && class_exists('WC_Seq_Order_Number')){
            $order_number = $order->get_order_number();
        }
        
        if ( is_a( $order, 'WC_Order' ) ) {
            $this->object                         = $order;
            $this->placeholders['{order_date}']   = wc_format_datetime( $this->object->get_date_created() );
            $this->placeholders['{order_number}'] = $this->object->get_order_number();
            $this->placeholders['{message_text}'] = $wooconvo_message;
            $this->placeholders['{billing_first_name}'] = $this->object->get_billing_first_name();
            $this->placeholders['{billing_last_name}'] = $this->object->get_billing_last_name();
            if( isset($_POST['files']) ){
                $this->placeholders['{file_link}'] = $wooconvo->render_attachments($_POST['files']);
            }
        }

        $subject = $this->get_subject().' Order no  #'.$order_number;
        $subject = sprintf(__("%s", 'wooconvo'),$subject);
        
        $this->subject = $subject;
        
        if ( $this->is_enabled() ) {
            
            $email_msg = $this->get_content();
            $this->send( $this->recipient, $this->get_subject(), $email_msg, $this->get_headers(), '' );
            // var_dump('send',$send_email, $this->recipient, $this->get_headers());
        }
        
        $this->restore_locale();
        
    }
    
    
    function get_content_after_vars() {
        
        $message = $this->get_content();
        
        foreach($this->placeholders as $var => $val){
            $message = str_replace("{$var}", $val, $message);
        }
        
        return $message;
    }
    
    public function get_content_html() {
      ob_start();
      wc_get_template( $this->template_html, array(
            'order'              => $this->object,
            'email_heading'      => $this->get_heading(),
            'additional_content' => $this->get_additional_content(),
            'sent_to_admin'      => true,
            'plain_text'         => false,
            'email'              => $this,
        ), '', $this->template_base );
        return ob_get_clean();
    }
    
    public function get_content_plain() {
        ob_start();
        wc_get_template( $this->template_plain, array(
                'order'              => $this->object,
                'email_heading'      => $this->get_heading(),
                'additional_content' => $this->get_additional_content(),
                'sent_to_admin'      => false,
                'plain_text'         => true,
                'email'              => $this,
            ), '', $this->template_base );
        return ob_get_clean();
      }
    
    function load_templates($file_name, $variables=array('')){

		extract($variables);

		$file_path = WOOCONVO_PATH . "/templates/vendor/{$file_name}";
	
		if (file_exists($file_path))
			require($file_path);
		else
			die('Could not load file '.$file_path);
	}
    
    public function init_form_fields() {

        $this->form_fields = array(
            'enabled'    => array(
                'title'   => 'Enable/Disable',
                'type'    => 'checkbox',
                'label'   => 'Enable this email notification',
                'default' => 'yes'
            ),
            'recipient'  => array(
                'title'       => 'Recipient(s)',
                'type'        => 'text',
                'description' => sprintf( 'Enter recipients (comma separated) for this email.', '' ),
                'placeholder' => '',
                'default'     => ''
            ),
            'subject'    => array(
                'title'       => 'Subject',
                'type'        => 'text',
                'description' => sprintf( 'This controls the email subject line. Leave blank to use the default subject: <code>%s</code>.', $this->subject ),
                'placeholder' => '',
                'default'     => ''
            ),
            'heading'    => array(
                'title'       => 'Email Heading',
                'type'        => 'text',
                'description' => sprintf( __( 'This controls the main heading contained within the email notification. Leave blank to use the default heading: <code>%s</code>.' ), $this->heading ),
                'placeholder' => '',
                'default'     => ''
            ),
            'additional_content'    => array(
                'title'       => 'Additional Message',
                'type'        => 'textarea',
                'description' => __('Any extra message you want to sent in notification email. Vars can be added {order_date}, {order_number}, {message_text}, {billing_last_name}, {billing_last_name}, {file_link}', 'woocono'),
                'placeholder' => '',
                'default'     => ''
            ),
            'email_type' => array(
                'title'       => 'Email type',
                'type'        => 'select',
                'description' => 'Choose which format of email to send.',
                'default'     => 'html',
                'class'       => 'email_type',
                'options'     => array(
                                'html'      => 'HTML',
                                'plain'      => 'Plain Text',
                                'multipart' 	=> __( 'Multipart', 'woocono' ),
                    )
            )
        );
    }
    
}